/* Sistemas Integrados TECNISA

Nome: 8982_SUPTRGS_LOG_SUP_FILGRUPFILI.SQL

Descrio:
   Trigger para gravar o registro de alteraes na tabela de agrupamento de filiais.

Criao:
   24/04/2007 - Raquel Cunha
*/

/* Tabela FILGRUPFILI: Agrupamento de Filiais. */
/* Descrio: A trigger insere registros na tabela LOGOPERA a partir de alteraes na tabela FILGRUPFILI*/
/* Objetivo:  Gerar um log que vai registrar as alteraes na tabela Agrupamentoo de Filial,
              utilizando a tabela Geral de Logs de Operaes*/

IF EXISTS (SELECT * FROM SYSOBJECTS O, SYSUSERS U
           WHERE O.NAME = 'LOG_SUP_FILGRUPFILI' AND
                 TYPE = 'TR' 		                AND
	              U.UID = O.UID                   AND
	              U.NAME = USER)
DROP TRIGGER LOG_SUP_FILGRUPFILI
GO


CREATE  TRIGGER LOG_SUP_FILGRUPFILI
ON FILGRUPFILI
FOR INSERT, UPDATE, DELETE
AS
   DECLARE  @V_USUARIO   VARCHAR(40);
   DECLARE  @V_TIPO      VARCHAR(1);
   DECLARE  @V_ITPESQ    VARCHAR(40);
   DECLARE  @V_DESC      VARCHAR(300);
   DECLARE  @V_DTOPER    DATETIME;

/*VARIVEIS DO CURSOR C_CURSOR*/

   DECLARE @V_ID_COMANDO        VARCHAR(1) ;

   DECLARE @V_OLD_CDGRUPFILI    VARCHAR(10);
   DECLARE @V_OLD_CDFILIAL      VARCHAR(4);

   DECLARE @V_NEW_CDGRUPFILI    VARCHAR(10);
   DECLARE @V_NEW_CDFILIAL      VARCHAR(4);

BEGIN

   SET @V_DESC     = '';
   SET @V_TIPO     = '0';

   EXEC NMUSUARIO @V_USUARIO;
   SET @V_USUARIO = ISNULL(@V_USUARIO, ' ');

   DECLARE C_CURSOR CURSOR FOR

      SELECT
         'U' IDCOMANDO,
         INSERTED.CDGRUPFILI,
         INSERTED.CDFILIAL,
         DELETED.CDGRUPFILI,
         DELETED.CDFILIAL
      FROM
         INSERTED,
         DELETED
      WHERE
         INSERTED.CDGRUPFILI = DELETED.CDGRUPFILI AND
         INSERTED.CDFILIAL   = DELETED.CDFILIAL

      UNION ALL

      SELECT
         'I' IDCOMANDO,
         NULL,
         NULL,
         INSERTED.CDGRUPFILI,
         INSERTED.CDFILIAL
      FROM
         INSERTED
      WHERE
         CDGRUPFILI+CDFILIAL  NOT IN (SELECT CDGRUPFILI+CDFILIAL  FROM DELETED)

      UNION ALL

      SELECT
         'D' IDCOMANDO,
         NULL,
         NULL,
         DELETED.CDGRUPFILI,
         DELETED.CDFILIAL
      FROM
         DELETED
      WHERE
         CDGRUPFILI+CDFILIAL  NOT IN (SELECT CDGRUPFILI+CDFILIAL  FROM INSERTED);


   OPEN C_CURSOR;
   FETCH NEXT FROM C_CURSOR INTO @V_ID_COMANDO,
                                 @V_OLD_CDGRUPFILI,
                                 @V_OLD_CDFILIAL,
                                 @V_NEW_CDGRUPFILI,
                                 @V_NEW_CDFILIAL;

   WHILE (@@FETCH_STATUS = 0) BEGIN

      IF NOT @V_USUARIO IS NULL BEGIN
         IF @V_ID_COMANDO= 'D' /*DELETING*/ BEGIN
            SET @V_TIPO = '3';
            IF @V_OLD_CDGRUPFILI IS NOT NULL BEGIN
               SET @V_DESC = @V_DESC + 'Agrupamento=' + @V_OLD_CDGRUPFILI;
            END;
            IF @V_OLD_CDFILIAL IS NOT NULL BEGIN
               SET @V_DESC = @V_DESC + ' Filial=' + @V_OLD_CDFILIAL;
            END;

            SET @V_ITPESQ = @V_OLD_CDGRUPFILI + @V_OLD_CDFILIAL;
        END
        ELSE

        IF @V_ID_COMANDO= 'U' /*UPDATING*/ BEGIN

           IF (@V_OLD_CDGRUPFILI   <> @V_NEW_CDGRUPFILI) OR
              (@V_OLD_CDFILIAL     <> @V_NEW_CDFILIAL  ) BEGIN

              SET  @V_TIPO   = '2';
              SET  @V_ITPESQ = @V_OLD_CDGRUPFILI  +
                               @V_OLD_CDFILIAL;

           END;
        END
        ELSE
           SET @V_TIPO   = '1';
              SET  @V_ITPESQ = @V_NEW_CDGRUPFILI  +
                               @V_NEW_CDFILIAL;
        END;

      IF ISNULL(@V_OLD_CDGRUPFILI, '') <> ISNULL(@V_NEW_CDGRUPFILI, '') BEGIN
         SET @V_DESC = @V_DESC + 'Agrupamento=' + @V_NEW_CDGRUPFILI;
      END;
      IF ISNULL(@V_OLD_CDFILIAL, '') <> ISNULL(@V_NEW_CDFILIAL, '') BEGIN
         SET @V_DESC = @V_DESC + ' Filial=' + @V_NEW_CDFILIAL;
      END;

      IF (@V_TIPO <> '0')  BEGIN
         IF NOT @V_DESC IS NULL BEGIN
            EXEC NMUSUARIO @V_USUARIO;
            SET  @V_DTOPER = GETDATE();
            INSERT INTO LOGOPERA
                       (NMTABELA, DTOPERACAO, NMRESPOPER,
                        IDTIPOOPER, CDPESQITEM, DSOPERACAO, CDFILLOGOPER)
                   VALUES
                       ('FILGRUPFILI', @V_DTOPER, @V_USUARIO,
                        @V_TIPO, @V_ITPESQ, @V_DESC, @V_NEW_CDFILIAL);
         END;
      END;
      FETCH NEXT FROM C_CURSOR INTO @V_ID_COMANDO,
                                    @V_OLD_CDGRUPFILI,
                                    @V_OLD_CDFILIAL,
                                    @V_NEW_CDGRUPFILI,
                                    @V_NEW_CDFILIAL;
   END;

   CLOSE      C_CURSOR;
   DEALLOCATE C_CURSOR;
END;
 GO

-- VERSAO --
EXEC ATUVEROBJ 'LOG_SUP_FILGRUPFILI','4.11.107';
GO

